@@ -1,5 +1,7 @@
 import hashlib
 
+HASH_VERSION = 'v1'
+
 
 def uri_and_hash_from_dict(params, remove_keys: list = []):
     """Returns both uri and hash for a given dict, ignoring specific keys"""
@@ -9,11 +11,11 @@ def uri_and_hash_from_dict(params, remove_keys: list = []):
     return (uri, query_hash)
 
 
-def hash_from_uri_string(uri_string:str):
+def hash_from_uri_string(uri_string: str):
     """Hashes a string for use with SERP components in the ecosystem"""
     hasher = hashlib.sha1()
     hasher.update(uri_string.encode('utf-8'))
-    return hasher.hexdigest()
+    return f"{HASH_VERSION}_{hasher.hexdigest()}"
 
 
 def uri_string_from_dict(input):
